function putvolumes (handle, volumes, slices, frames)
%PUTVOLUMES  Writes whole volumes to an open MINC file.
%
%      putvolumes (handle, volumes [, slices [, frames]])
%
%  writes volumes (a matrix with each column containing a whole image)
%  to the MINC file specified by handle, at the slices/frames specfied
%  by the slices/frames vectors.
%
%  EXAMPLES
%    
%  SEE ALSO  newimage, openimage, getvolumes

% ------------------------------ MNI Header ----------------------------------
%@NAME       : putvolumes
%@INPUT      : handle - to an already-created image in MATLAB
%              volumes - matrix of volumes, where the columns of the matrix
%              contain whole volumes laid out linearly
%              slices, frames - vectors describing which slices/frames
%              the columns of volumes correspond to.  Only one of these
%              vectors may have multiple elements, i.e. all the columns
%              of volumes must correspond to either a certain slice and
%              various frames (listed in the frames vector) or a certain
%              frame and various slices (listed in the slices vector).
%@OUTPUT     : 
%@RETURNS    : (none)
%@DESCRIPTION: Write volumes to the MINC file associated with handle.  If
%              there is no such MINC file, no action is taken.
%@METHOD     : 
%@GLOBALS    : 
%@CALLS      : miwritevolumes (if there is a MINC file)
%@CREATED    : November 2001, Rick Hoge
%@VERSION    : $Id: putvolumes.m,v 1.1 2001/11/24 00:53:49 rhoge Exp $
%              $Name:  $
%-----------------------------------------------------------------------------


if ((nargin < 2) | (nargin >4))
    help putvolumes
    error ('Incorrect number of arguments.');
end
 
eval(['global Flags' int2str(handle)]);
eval(['Flags = Flags' int2str(handle) ';']);
if (~ Flags(1))
   error ('Cannot write to a read-only file');
end

% if frames not supplied, make it empty

if (nargin < 3)
   slices = [];
end

if (nargin < 4)
   frames = [];
end

% figure out number of volumes we expect to see in matrix volumes

if (isempty (slices) & isempty (frames))
   num_required = 1;
else
   num_required = max (length(slices), length(frames));
end

% check that slices and frames are valid

error (check_rcsf (handle, slices, frames));

[im_len, num_im] = size (volumes);

if (num_required ~= num_im)
   errmsg = sprintf ('%d slices and %d frames were specified, which means I need to write %d volumes into the file -- but the image matrix has %d columns',...
            length(slices), length(frames), num_required, num_im);
   error (errmsg);
end

% make the MINC file's name global and copy to a local variable

eval(['global Filename' int2str(handle)]);
eval(['filename = Filename' int2str(handle) ';']);

if ~isempty (filename)        % write volumes to MINC file if there is one
   miwritevolumes (filename, volumes, slices, frames);
else
   disp ('Warning: cannot put volumes without a filename');
end
